﻿/* Copyright (C) Siemens AG, 2012. All Rights Reserved.
 * Author: Roland Eckl, Corporate Technology
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Windows;

namespace RVM.Helpers
{
    /// <summary>
    /// Selects the appropriate dispatcher (WPF or WinForms), checks if the dispatcher has access to the UI thread and calls
    /// the action directly or over the dispatcher.
    /// TODO: Works with WPF dispatcher only at the moment. Check if this can simply be used in Forms, too!
    /// </summary>
    public static class SmartDispatcher
    {
        /// <summary>
        /// Invokes an action on an appropriate dispatcher.
        /// </summary>
        /// <param name="action"></param>
        public static void BeginInvoke(Action action)
        {
            if (Application.Current.Dispatcher.CheckAccess())
                action();
            else
                Application.Current.Dispatcher.BeginInvoke(action);
        }
    }
}
