﻿/* Copyright (C) Siemens AG, 2012. All Rights Reserved.
 * Author: Roland Eckl, Corporate Technology
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections;
using System.Collections.Specialized;

namespace RVM.Infrastructure
{
    /// <summary>
    /// Detailed information for the CollectionChanged event.
    /// Mimics somehow the NotifyCollectionChangedEventArgs class.
    /// TODO: Why not inherit directly from NotifyColl....?
    /// </summary>
    [Serializable]
    public class CollectionChangedEventArgs
    {
        /// <summary>
        /// The actual action performed on a collection.
        /// </summary>
        public NotifyCollectionChangedAction Action;

        /// <summary>
        /// List of changed/new items within the collection.
        /// </summary>
        public IList NewItems;

        /// <summary>
        /// Starting index of changed elements.
        /// </summary>
        public int NewIndex;

        /// <summary>
        /// List of items within the collection affected by a Replace, Remove, or Move action.
        /// </summary>
        public IList OldItems;

        /// <summary>
        /// Starting index of old elements.
        /// </summary>
        public int OldIndex;
    }
}
