﻿/* Copyright (C) Siemens AG, 2012. All Rights Reserved.
 * Author: Roland Eckl, Corporate Technology
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;


namespace RVM.Infrastructure.Communication
{
    /// <summary>
    /// Transport-independent interface for importers.
    /// </summary>
    public interface IViewModelImporter
    {
        /// <summary>
        /// Connection state.
        /// </summary>
        bool Connected { get; }

        /// <summary>
        /// Id of linked exporter
        /// </summary>
        string Id { get; }

        /// <summary>
        /// Connect to exporter
        /// </summary>
        /// <returns></returns>
        bool Start();

        /// <summary>
        /// Disconnect from exporter
        /// </summary>
        /// <returns></returns>
        bool Stop();

        /// <summary>
        /// Get a viewmodel from the exporter
        /// </summary>
        /// <param name="t">Type of ViewModel, which will be wired up with the remote agent.</param>
        /// <param name="id">Unique ID of an exported viewmodel</param>
        /// <returns></returns>
        RemotableViewModel GetViewModel(Type t, string id);

        /// <summary>
        /// Event which indicates if the connection changed into faulted state.
        /// </summary>
        event EventHandler Faulted;
    }
}
