﻿/* Copyright (C) Siemens AG, 2012. All Rights Reserved.
 * Author: Roland Eckl, Corporate Technology
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System.ServiceModel;


namespace RVM.Infrastructure.Communication.WCF.NetPipe
{
    /// <summary>
    /// Callback class
    /// </summary>
    [CallbackBehavior(ConcurrencyMode = ConcurrencyMode.Multiple, UseSynchronizationContext = false)]
    public class NetPipeViewModelCallback : IViewModelCallback
    {
        /// <summary>
        /// Raises RemotePropertyChanged event.
        /// </summary>
        /// <param name="id">Unique ID of the ViewModel</param>
        /// <param name="property">Affected property</param>
        public void FireRemotePropertyChanged(string id, string property)
        {
            if (RemotePropertyChanged != null)
                RemotePropertyChanged(id, property);
        }

        /// <summary>
        /// Raises RemoteCollectionChanged event.
        /// </summary>
        /// <param name="id">Unique ID of the ViewModel</param>
        /// <param name="property">Affected property</param>
        /// <param name="details">Details on performed action</param>
        public void FireRemoteCollectionChanged(string id, string property, CollectionChangedEventArgs details)
        {
            if (RemoteCollectionChanged != null)
            {
                // TODO: Check if affected element is serializable!
                RemoteCollectionChanged(id, property, details);
            }
        }

        /// <summary>
        /// Event which signals that some property of an exported ViewModel changed.
        /// </summary>
        public event RemotePropertyChangedDelegate RemotePropertyChanged;

        /// <summary>
        /// Event which signals that some collection of an exported ViewModel changed.
        /// </summary>
        public event RemoteCollectionChangedDelegate RemoteCollectionChanged;
    }
}
