﻿/* Copyright (C) Siemens AG, 2012. All Rights Reserved.
 * Author: Roland Eckl, Corporate Technology
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


namespace RVM.Infrastructure
{
    /// <summary>
    /// Identifies a session, which is used among importer and exporters which are compatible.
    /// </summary>
    public abstract class Session
    {
        /// <summary>
        /// Private member, holding the session Id.
        /// </summary>
        private string _uniqueID = string.Empty;

        /// <summary>
        /// Constructor setting the Session's Id.
        /// NOTE: Id should be constant! Do not call Guid.NewGuid, because importer and exporters would be hard to synchronize in such a spontanous compound.
        /// </summary>
        /// <param name="id">UniqueId for this session</param>
        protected Session(string id)
        {
            _uniqueID = id;
        }

        /// <summary>
        /// Public Accessor for the session Id.
        /// </summary>
        public string Id
        {
            get { return _uniqueID; }
        }
    }
}
