﻿/* Copyright (C) Siemens AG, 2012. All Rights Reserved.
 * Author: Roland Eckl, Corporate Technology
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using RVM.Infrastructure;


namespace RvmShared
{
    /// <summary>
    /// Simple demonstration how to use session's in RVM.
    /// The session itself is a singleton which calls a constant string on the base class' constructor.
    /// </summary>
    public class SimpleSession : Session
    {
        /// <summary>
        /// Static instance of the session. Created once the type SimpleSession is used.
        /// </summary>
        private static SimpleSession _instance = new SimpleSession();

        /// <summary>
        /// Private constructor with hardcoded GUID for the session in the SimpleDemo.
        /// </summary>
        private SimpleSession() : base("eee513cd-5266-4eb6-bc58-9dce5ac386cf")
        {}

        /// <summary>
        /// Accessor to the singleton.
        /// </summary>
        public static SimpleSession Current { get { return _instance; } }

        /// <summary>
        /// Process name used to identify possible exporters for this session.
        /// </summary>
        public static string ProcessName = "RvmExporter";
    }
}
